@@ -628,7 +628,7 @@ static int afpacket_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr,
         goto err;
     }
 
-    /* 
+    /*
      * Determine the dimensions of the kernel RX ring(s) to request.
      */
     /* 1. Find the total desired packet buffer memory for all instances. */
@@ -990,7 +990,7 @@ static int afpacket_daq_get_device_index(void *handle, const char *string)
 }
 
 #ifdef BUILDING_SO
-SO_PUBLIC const DAQ_Module_t DAQ_MODULE_DATA =
+DAQ_SO_PUBLIC const DAQ_Module_t DAQ_MODULE_DATA =
 #else
 const DAQ_Module_t afpacket_daq_module_data =
 #endif
