@@ -1,4 +1,3 @@
-/* $Id: daq_ipfw.c,v 1.13 2010/12/08 16:03:09 rcombs Exp $ */
 /*
  ** Portions Copyright (C) 1998-2010 Sourcefire, Inc.
  **
@@ -422,7 +421,7 @@ static int ipfw_daq_get_device_index(void* handle, const char* device)
 //-------------------------------------------------------------------------
 
 #ifdef BUILDING_SO
-SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
+DAQ_SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
 #else
 DAQ_Module_t ipfw_daq_module_data =
 #endif
