@@ -1,4 +1,3 @@
-/* $Id: daq_ipq.c,v 1.20 2010/12/08 15:53:58 rcombs Exp $ */
 /*
  ** Portions Copyright (C) 1998-2010 Sourcefire, Inc.
  **
@@ -32,14 +31,18 @@
 
 #include <netinet/ip.h>
 
+#ifdef HAVE_DUMBNET_H
+#include <dumbnet.h>
+#else
 #include <dnet.h>
+#endif
 #include <linux/netfilter.h>
 #include <libipq.h>
 
 #include "daq_api.h"
 #include "sfbpf.h"
 
-#define DAQ_MOD_VERSION  4
+#define DAQ_MOD_VERSION  5
 
 #define DAQ_TYPE (DAQ_TYPE_INTF_CAPABLE | DAQ_TYPE_INLINE_CAPABLE | \
                   DAQ_TYPE_MULTI_INSTANCE | DAQ_TYPE_NO_UNPRIV)
@@ -258,7 +261,13 @@ static void ipq_daq_shutdown (void* handle)
 static void SetPktHdr(
     IpqImpl* impl, ipq_packet_msg_t* m, DAQ_PktHdr_t* phdr)
 {
-    if ( !m->timestamp_sec )
+    // if ipq fails to provide a timestamp, we fall back on tod
+    if ( m->timestamp_sec && (m->timestamp_sec != 0) )
+    {
+        phdr->ts.tv_sec = m->timestamp_sec;
+        phdr->ts.tv_usec = m->timestamp_usec;
+    }
+    else
     {
         struct timeval t;
         gettimeofday(&t, NULL);
@@ -266,11 +275,6 @@ static void SetPktHdr(
         phdr->ts.tv_sec = t.tv_sec;
         phdr->ts.tv_usec = t.tv_usec;
     }
-    else
-    {
-        phdr->ts.tv_sec = m->timestamp_sec;
-        phdr->ts.tv_usec = m->timestamp_usec;
-    }
     phdr->caplen = (m->data_len <= impl->snaplen) ? m->data_len : impl->snaplen;
     phdr->pktlen = m->data_len;
 }
@@ -511,7 +515,7 @@ static int ipq_daq_get_device_index(void* handle, const char* device)
 //-------------------------------------------------------------------------
 
 #ifdef BUILDING_SO
-SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
+DAQ_SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
 #else
 DAQ_Module_t ipq_daq_module_data =
 #endif
