@@ -1,4 +1,3 @@
-/* $Id: daq_nfq.c,v 1.19 2010/12/08 15:53:58 rcombs Exp $ */
 /*
  ** Portions Copyright (C) 1998-2010 Sourcefire, Inc.
  **
@@ -32,14 +31,18 @@
 
 #include <netinet/ip.h>
 
+#ifdef HAVE_DUMBNET_H
+#include <dumbnet.h>
+#else
 #include <dnet.h>
+#endif
 #include <linux/netfilter.h>
 #include <libnetfilter_queue/libnetfilter_queue.h>
 
 #include "daq_api.h"
 #include "sfbpf.h"
 
-#define DAQ_MOD_VERSION  4
+#define DAQ_MOD_VERSION  6
 
 #define DAQ_NAME "nfq"
 #define DAQ_TYPE (DAQ_TYPE_INTF_CAPABLE | DAQ_TYPE_INLINE_CAPABLE | \
@@ -183,7 +186,7 @@ static int nfq_daq_get_setup (
     }
 
     impl->snaplen = cfg->snaplen ? cfg->snaplen : IP_MAXPACKET;
-    impl->timeout = cfg->timeout;
+    impl->timeout = cfg->timeout / 1000;  // convert ms to secs
     impl->passive = ( cfg->mode == DAQ_MODE_PASSIVE );
 
     return DAQ_SUCCESS;
@@ -334,6 +337,16 @@ static int nfq_daq_initialize (
         }
     }
 
+    // from Florign Westphal ...
+    // tell kernel that we do not need to know about queue overflows.
+    // Without this, read operations on the netlink socket will fail
+    // with ENOBUFS on queue overrun.
+    {
+        int option = 1;
+        setsockopt(impl->sock, SOL_NETLINK, NETLINK_NO_ENOBUFS,
+            &option, sizeof(option));
+    }
+
     impl->state = DAQ_STATE_INITIALIZED;
 
     *handle = impl;
@@ -388,7 +401,10 @@ static inline int SetPktHdr (
     hdr->pktlen = len;
     hdr->flags = 0;
 
-    nfq_get_timestamp(nfad, &hdr->ts);
+    // if nfq fails to provide a timestamp, we fall back on tod
+    if ( nfq_get_timestamp(nfad, &hdr->ts) )
+        gettimeofday(&hdr->ts, NULL);
+
     hdr->device_index = nfq_get_physindev(nfad);
 
     return 0;
@@ -658,7 +674,7 @@ static int nfq_daq_get_device_index(void* handle, const char* device)
 //-------------------------------------------------------------------------
 
 #ifdef BUILDING_SO
-SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
+DAQ_SO_PUBLIC DAQ_Module_t DAQ_MODULE_DATA =
 #else
 DAQ_Module_t nfq_daq_module_data =
 #endif
