@@ -216,7 +216,7 @@ static int pcap_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr, char
     for (entry = config->values; entry; entry = entry->next)
     {
         if (!strcmp(entry->key, "buffer_size"))
-            context->buffer_size = strtol(entry->key, NULL, 10);
+            context->buffer_size = strtol(entry->value, NULL, 10);
     }
     /* Try to account for legacy PCAP_FRAMES environment variable if we weren't passed a buffer size. */
     if (context->buffer_size == 0)
@@ -544,7 +544,7 @@ static int pcap_daq_get_device_index(void *handle, const char *device)
 }
 
 #ifdef BUILDING_SO
-SO_PUBLIC const DAQ_Module_t DAQ_MODULE_DATA =
+DAQ_SO_PUBLIC const DAQ_Module_t DAQ_MODULE_DATA =
 #else
 const DAQ_Module_t pcap_daq_module_data =
 #endif
